@@ -64,7 +64,7 @@ class Configuration(UserDict):
         self._emailer = None
 
         hdx_base_config_found = False
-        hdx_base_config_dict = kwargs.get("hdx_base_config_dict", None)
+        hdx_base_config_dict = kwargs.get("hdx_base_config_dict")
         if hdx_base_config_dict:
             hdx_base_config_found = True
             logger.info("Loading HDX base configuration from dictionary")
@@ -101,7 +101,7 @@ class Configuration(UserDict):
             hdx_base_config_dict = load_yaml(hdx_base_config_yaml)
 
         hdx_config_found = False
-        hdx_config_dict = kwargs.get("hdx_config_dict", None)
+        hdx_config_dict = kwargs.get("hdx_config_dict")
         if hdx_config_dict:
             hdx_config_found = True
             logger.info("Loading HDX configuration from dictionary")
@@ -146,7 +146,7 @@ class Configuration(UserDict):
         )
 
         project_config_found = False
-        project_config_dict = kwargs.get("project_config_dict", None)
+        project_config_dict = kwargs.get("project_config_dict")
         if project_config_dict is not None:
             project_config_found = True
             logger.info("Loading project configuration from dictionary")
@@ -194,32 +194,44 @@ class Configuration(UserDict):
                 self.user_agent = UserAgent.get(
                     prefix=Configuration.prefix, **self.data
                 )
-        hdx_url = kwargs.get("hdx_url", self.data.get("hdx_url"))
+        hdx_url = kwargs.get("hdx_url")
+        if not hdx_url:
+            hdx_url = self.data.get("hdx_url")
         if hdx_url:
             hdx_site = "custom"
             self.hdx_site = "hdx_custom_site"
             hdx_url = hdx_url.rstrip("/")
             self.data[self.hdx_site] = {"url": hdx_url}
         else:
-            hdx_site = kwargs.get(
-                "hdx_site", self.data.get("hdx_site", "stage")
-            )
+            hdx_site = kwargs.get("hdx_site")
+            if not hdx_site:
+                hdx_site = self.data.get("hdx_site")
+                if not hdx_site:
+                    hdx_site = "stage"
             self.hdx_site = f"hdx_{hdx_site}_site"
             if self.hdx_site not in self.data:
                 raise ConfigurationError(
                     f"{self.hdx_site} not defined in configuration!"
                 )
-        self.hdx_read_only = kwargs.get(
-            "hdx_read_only", self.data.get("hdx_read_only", False)
-        )
+        hdx_read_only = kwargs.get("hdx_read_only")
+        if hdx_read_only is None:
+            hdx_read_only = self.data.get("hdx_read_only")
+            if hdx_read_only is None:
+                hdx_read_only = False
+        self.hdx_read_only = hdx_read_only
         logger.info(f"Read only access to HDX: {str(self.hdx_read_only)}")
         hdx_key_site = f"hdx_key_{hdx_site}"
-        hdx_key = kwargs.get(hdx_key_site, self.data.get(hdx_key_site))
+        hdx_key = kwargs.get(hdx_key_site)
+        if not hdx_key:
+            hdx_key = self.data.get(hdx_key_site)
+            if not hdx_key:
+                hdx_key = kwargs.get("hdx_key")
+                if not hdx_key:
+                    hdx_key = self.data.get("hdx_key")
         if hdx_key:
             self.hdx_key = hdx_key
-        else:
-            self.hdx_key = kwargs.get("hdx_key", self.data.get("hdx_key"))
-        if not self.hdx_key and not self.hdx_read_only:
+            return
+        if not self.hdx_read_only:
             raise ConfigurationError(
                 "No HDX API key supplied as a parameter or in configuration!"
             )
